@@ -857,6 +857,7 @@ class LaharFlowData(object):
                  ax=None,
                  vmin=0.1,
                  vmax=None,
+                 vcut=None,
                  interpolation='nearest',
                  cmap=plt.cm.viridis,
                  cax=None,
@@ -881,6 +882,9 @@ class LaharFlowData(object):
         
         if vmin is not None:
             data = np.ma.masked_less(dataArray.data, vmin)
+        
+        if vcut is not None:
+            data = np.ma.masked_inside(data, vcut[0], vcut[1])
 
         if ax is None:
             fig, ax = plt.subplots()
